@@ -1,4 +1,4 @@
-# $Id: Geometry.pm,v 1.3 2002/06/25 14:45:13 dk Exp $
+# $Id: Geometry.pm,v 1.4 2006/10/07 23:12:36 dk Exp $
 package IPA::Geometry;
 use IPA;
 use strict;
@@ -9,7 +9,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter DynaLoader);
 $VERSION = '0.01';
 @EXPORT = qw();
-@EXPORT_OK = qw(mirror shift_rotate);
+@EXPORT_OK = qw(mirror shift_rotate rotate90 rotate180);
 %EXPORT_TAGS = (one2one => [qw(mirror)]);
 sub dl_load_flags { 0x01 };
 
